import React, { useState, useRef } from "react";
import { TouchableOpacityComponent } from "react-native";
import {
  FlatList,
  SafeAreaView,
  StatusBar,
  StyleSheet,
  Text,
  View,
  Dimensions,
  TextInput,
} from "react-native";
import { Button, Overlay } from "react-native-elements";
import AppButton from "./AppButton";
import defaultStyles from "../config/styles";

const Item = ({ item, onPress, backgroundColor, textColor }) => (
  <Button
    title={item.title}
    buttonStyle={{
      borderRadius: 30,
      padding: 10,
      margin: 8,
      backgroundColor: defaultStyles.grey,
    }}
    onPress={() => {
      onPress();
    }}
  />
);

const TopList = ({
  actions,
  handleAddAction,
  actionsData,
  showOverlay,
  coso,
}) => {
  let handleOnAccept = null;
  const input = useRef(null);

  const [inputValue, setInputValue] = useState();
  const [overlay, setOverlay] = useState();
  const [overlayVisible, setOverlayVisible] = useState(true);
  const renderItem = ({ item }) => {
    const handleOnPress = () => {
      if (item.overlay == null) {
        handleAddAction({
          id: actions.length,
          name: item.title,
          actionId: item.actionId,
          idAction: item.idAction,
        });
      } else {
        showOverlay(item.overlay({ editOverlay: false }));
      }
    };

    return (
      <Item
        item={item}
        onPress={() => {
          handleOnPress();
        }}
      />
    );
  };

  return (
    <SafeAreaView style={styles.container}>
      <FlatList
        persistentScrollbar
        columnWrapperStyle={{ flexWrap: "wrap", justifyContent: "center" }}
        numColumns={100}
        data={actionsData}
        renderItem={renderItem}
        keyExtractor={(item) => item.idAction.toString()}
      />
      {overlay}
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    marginTop: "1%",
  },
  item: {
    padding: 20,
    marginVertical: 8,
    marginHorizontal: 16,
  },
  title: {
    fontSize: Dimensions.get("screen").width * 0.035,
  },
  overlay: {
    alignItems: "center",
    justifyContent: "space-around",
    width: "80%",
    borderRadius: 10,
    paddingVertical: "8%",
  },
});

export default TopList;
