import React, { useEffect, useState } from "react";
import {
  View,
  StyleSheet,
  Button,
  TextInput,
  Text,
  Alert,
  StatusBar,
  Dimensions,
  ImageBackground,
  Image,
} from "react-native";
import defaultStyles from "../config/styles";
import AppButton from "../components/AppButton";

function ConfigScreen({ navigation }) {
  useEffect(() => {}, []);

  const [timeoutError, setTimeoutError] = useState();
  const [ipServer, setIpServer] = useState();
  const [port, setPort] = useState();
  const [connecting, setConnecting] = useState(false);

  const [successConectionVisible, setSuccessConectionVisible] = useState(false);

  const checkConnection = async () => {
    //const SocketEndpoint = "ws://192.168.43.2:8000";
    const SocketEndpoint = "ws://" + ipServer + ":" + port;
    try {
      if (port == undefined || ipServer == undefined) {
        Alert.alert("Ops!", "No debe dejar campos vacios");
        return;
      }
      //console.log(1);
      let socket = new WebSocket(SocketEndpoint);
      socket.binaryType = "blob";
      //console.log("check");

      socket.onopen = () => {
        //console.log("open");
        socket.send("TestConnection");
        //console.log(2);
      };
      setConnecting(true);
      let timeout = setTimeout(() => {
        setConnecting(false);
        Alert.alert(
          "Ops!",
          "Se ha producido un error, verifica si el servidor esta activo, y/o si la direccion IP y el puerto son correctos"
        );
      }, 3000);
      setTimeoutError(timeout);

      socket.onmessage = function (event) {
        clearTimeout(timeout);
        setSuccessConectionVisible(true);
        setConnecting(false);
        setTimeout(() => {
          setSuccessConectionVisible(false);
          setConnecting(false);
          navigation.navigate("MainScreen", {
            port,
            ipServer,
          });
        }, 1000);
        //console.log("dataReceived1");
        //console.log(JSON.stringify(event));
        //console.log("dataReceived2");
      };
    } catch (error) {
      console.log("catch", error);
      Alert.alert(
        "Ops!",
        "Se ha producido un error, verifica si el servidor esta activo, y/o si la direccion IP y el puerto son correctos"
      );
    }
  };

  return (
    <ImageBackground
      blurRadius={0.7}
      source={require("../assets/background2.jpg")}
      style={{
        flex: 1,
        padding: 10,
        alignItems: "center",
        justifyContent: "center",
        paddingTop: StatusBar.currentHeight,
      }}
    >
      <Image
        source={require("../assets/logo.jpg")}
        style={{
          resizeMode: "contain",
          height: "6%",
          borderRadius: 120,
          position: "absolute",
          bottom: "15%",
        }}
      />
      {successConectionVisible && (
        <View style={styles.textContainer}>
          <Text style={styles.mainText}>Conección con el servidor exitosa</Text>
        </View>
      )}

      {connecting && (
        <View style={styles.textContainer}>
          <Text style={styles.mainText}>Conectando...</Text>
        </View>
      )}
      {!successConectionVisible && !connecting && (
        <>
          <View style={styles.textContainer}>
            <Text style={styles.mainText}>
              Por favor, ingresa la dirección ip y el puerto del servidor
            </Text>
          </View>
          <TextInput
            placeholder="Dirección ip"
            value={ipServer}
            style={styles.textInput}
            onChangeText={(text) => {
              setIpServer(text);
            }}
            placeholderTextColor={"white"}
            keyboardType="numeric"
          />
          <TextInput
            placeholder="Puerto"
            value={port}
            style={styles.textInput}
            onChangeText={(text) => {
              setPort(text);
            }}
            placeholderTextColor={"white"}
            keyboardType="numeric"
          />

          <View style={{ width: 150, marginTop: 10 }}>
            <AppButton
              color={defaultStyles.grey}
              title="Conectar"
              style={styles.buttonStyle}
              onPress={checkConnection}
            />
          </View>
        </>
      )}
    </ImageBackground>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: "#fff",
    alignItems: "center",
    justifyContent: "center",
  },
  buttonStyle: {
    marginTop: "10%",
    borderRadius: 10,
    padding: 20,
  },
  textInput: {
    width: "50%",
    marginTop: 30,
    borderColor: "white",
    borderWidth: 1,
    paddingHorizontal: 10,
    textAlign: "center",
    color: "white",
    padding: 6,
  },
  mainText: {
    fontSize: Dimensions.get("screen").width * 0.04,
    color: "white",
    fontWeight: "bold",
    marginBottom: "12%",
    textAlign: "center",
  },
  textContainer: { width: "80%" },
});

export default ConfigScreen;
